@@ -651,16 +651,19 @@ class VMUtils(object):
     def _get_mounted_disk_resource_from_path(self, disk_path, is_physical):
         if is_physical:
             class_name = self._RESOURCE_ALLOC_SETTING_DATA_CLASS
-            res_sub_type = self._PHYS_DISK_RES_SUB_TYPE
         else:
             class_name = self._STORAGE_ALLOC_SETTING_DATA_CLASS
-            res_sub_type = self._HARD_DISK_RES_SUB_TYPE
 
-        disk_resources = self._conn.query("SELECT * FROM %(class_name)s "
-                                          "WHERE ResourceSubType = "
-                                          "'%(res_sub_type)s'" %
-                                          {"class_name": class_name,
-                                           "res_sub_type": res_sub_type})
+        query = ("SELECT * FROM %(class_name)s WHERE ("
+                 "ResourceSubType='%(res_sub_type)s' OR "
+                 "ResourceSubType='%(res_sub_type_virt)s' OR "
+                 "ResourceSubType='%(res_sub_type_dvd)s')" % {
+                     'class_name': class_name,
+                     'res_sub_type': self._PHYS_DISK_RES_SUB_TYPE,
+                     'res_sub_type_virt': self._HARD_DISK_RES_SUB_TYPE,
+                     'res_sub_type_dvd': self._DVD_DISK_RES_SUB_TYPE})
+
+        disk_resources = self._conn.query(query)
 
         for disk_resource in disk_resources:
             if disk_resource.HostResource:
@@ -788,3 +791,26 @@ class VMUtils(object):
     def stop_vm_jobs(self, vm_name):
         vm = self._lookup_vm_check(vm_name)
         self._jobutils.stop_jobs(vm)
+
+    def enable_secure_boot(self, vm_name, msft_ca_required):
+        """Enables Secure Boot for the instance with the given name.
+
+        :param vm_name: The name of the VM for which Secure Boot will be
+                        enabled.
+        :param msft_ca_required: boolean specifying whether the VM will
+                                 require Microsoft UEFI Certificate
+                                 Authority for Secure Boot. Only Linux
+                                 guests require this CA.
+        """
+        vm = self._lookup_vm_check(vm_name)
+        vs_data = self._get_vm_setting_data(vm)
+        self._set_secure_boot(vs_data, msft_ca_required)
+        vs_man_svc = self._conn.Msvm_VirtualSystemManagementService()[0]
+        self._modify_virtual_system(vs_man_svc, vm.path_(), vs_data)
+
+    def _set_secure_boot(self, vs_data, msft_ca_required):
+        vs_data.SecureBootEnabled = True
+        if msft_ca_required:
+            raise exceptions.HyperVException(
+                _('UEFI SecureBoot is supported only on Windows instances for '
+                  'this Hyper-V version.'))
