@@ -80,3 +80,6 @@ TRUNK_ENDPOINT_MODE = 5
 TYPE_FLAT = 'flat'
 TYPE_LOCAL = 'local'
 TYPE_VLAN = 'vlan'
+
+SERIAL_CONSOLE_BUFFER_SIZE = 4 << 10
+MAX_CONSOLE_LOG_FILE_SIZE = 1 << 19  # 512kB
